OpBox

Struct OpBox 

pub struct OpBox { /* private fields */ }
A stack allocated alternative to Box for Op objects.

Implementations

Source

impl OpBox

pub fn new<T: Op>(op: T) -> Self

Create a new OpBox from a concrete Op object.

pub fn op_ref(&self) -> &dyn Op

Get a reference to the underlying Op object.

pub fn downcast<T: Op>(self) -> Option<T>

Downcast this OpBox to a concrete Op type.

Methods from Deref<Target = dyn Op>

pub fn is<__T: Op>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast_rc<__T: Op>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: Op>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.