pub struct OpBox { /* private fields */ }Implementations
Methods from Deref<Target = dyn Op>
Sourcepub fn is<__T: Op>(&self) -> bool
pub fn is<__T: Op>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast_rc<__T: Op>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: Op>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: Op>(&self) -> Option<&__T>
pub fn downcast_ref<__T: Op>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.